%rutherford_scattering
% Model of the particle detection rates predicted in a Geiger & Marsden
% style alpha particle scattering experiment by gold leaf foil.
%
% LAST UPDATED by Andy French 8/2/2016

function rutherford_scattering

%% Inputs %%

%Atomic number of gold
Z = 79;

%Define nucleus radius /fm (Uranium is 15fm)
nucleus_radius = 10;

%Charge on the electron /C
qe = 1.602e-19;

%Permittivity of free space /Fm^-1
eps0 = 8.85e-12;

%Speed of light /ms^-1
c = 299792458;

%Alpha particle KE in MeV (then convert to J)
E = 3;
E = E*1e6*qe;

%Mass of alpha particle /kg
m = 6.64465723082e-27;

%Number of atoms per cubic metre
n = 5.9e28;

%Foil thickness /m
t = 1.5e-6;

%Detector area /mm^2 (the convert to m^2)
A = 15;
A = 15*( (1e-3)^2 );

%Distance of detector to foil (assume on circular arc) /m
r = 0.1;

%Counts per minute incident upon foil (counts per min)
%(If the source is placed very close to the foil, this is essentially
%the activity of the source.
Nfoil = 1000;

%Scattering angle for alpha particle trajectory plot /deg. Then convert to
%radians
PHI = 100;
PHI = PHI*pi/180;

%Fix trajectory plot scale in F = b/sin(  (pi-PHI)/2 ) units
xlimits = [-2,4];
ylimits = [-3,3];

%Define numer of evaluation steps for deflection angle
S = 1000;

%Fontsize for graphs 
fsize = 18;

%

%% Model %%

%Classical initial velocity of alpha particle /ms^-1
u = sqrt( 2*E/m );

%Alpha particle velocity as a faction of the speed of light
u_over_c = u/c;

%Generate array of scattering angles
phi = linspace( 0.01,pi,S );

%Predict detector count rates /min
k = A*t*n/(r^2);
k = k * ( (Z*qe^2) / (4*pi*eps0*E) )^2;
N = Nfoil*k.*( sin(phi/2) ).^(-4);

%Straight line graph for analysis (i.e. gradient should be 4), y intercept
%should be log10(k).
y = log10(N/Nfoil);
x = log10( 1./(sin(phi/2)) );

%Determine impact parameter /m
b = Z*(qe^2)*cot(PHI/2)/( 8*pi*eps0*E );

%Determine initial trajectory elevation angle /radians
epsilon = (pi - PHI)/2;

%Compute trajectory constants
A = 1/(b*sin(epsilon));
B = -Z*(qe^2)/(8*pi*eps0*E*b^2);
F = b/sin(epsilon);
F = F/1e-15;

%Update trajectory plot axes limits /fm
xlimits = xlimits*F;
ylimits = ylimits*F;

%Define polar angles /radians
theta = linspace( -0.9*epsilon,0.9*epsilon, S );

%Define trajectory radius /fm
r = 1./( A*cos(theta) + B );
r = r/1e-15;

%Define trajectory time /s vs angle.
t = integrate( theta(1)*ones(1,S),theta, theta, ((r*1e-15).^2)/(u.*b) );

%Calculate r and theta at equally spaced times
r = interp1( t, r, linspace(0,t(end),S) );
theta = interp1( t, theta, linspace(0,t(end),S) );
t = interp1( t, t, linspace(0,t(end),S) );

%Define trajectory x,y coordinates /fm (note nucleus is at [-F,0] )
x_traj = r.*cos(theta)-F;
y_traj = r.*sin(theta);

%Define unscattered trajector(ies)
x_us1 = x_traj(end) - 20*F*linspace(0,1,S)*cos(epsilon);
y_us1 = y_traj(end) - 20*F*linspace(0,1,S)*sin(epsilon);
x_us2 = x_traj(1) - 20*F*linspace(0,1,S)*cos(epsilon);
y_us2 = y_traj(1) + 20*F*linspace(0,1,S)*sin(epsilon);

%Define nucleus plot
tt = linspace(0,2*pi,S);
x_nuc = nucleus_radius*cos(tt) - F;
y_nuc = nucleus_radius*sin(tt);

%

%% Plot Graphs %%

%Particle count vs scattering angle. i.e. cosec^4 dependence
figure( 'name', 'rutherford scattering','color',[1 1 1] )
plot( phi*180/pi, log10(N) );
xlabel('Scattering angle /deg','fontsize',fsize)
ylabel('log_{10}( Particle count /min )','fontsize',fsize)
title('Model of Rutherford scattering experiment','fontsize',fsize)
axis tight
grid on
set(gca,'fontsize',fsize)
print( gcf, 'rutherford particle count.png','-dpng','-r300');
close(gcf);

%y = mcx + c analysis graph, to investiagate cosec^4 dependence
figure( 'name', 'rutherford scattering','color',[1 1 1] )
plot( x, y );
xlabel('x','fontsize',fsize)
ylabel('y','fontsize',fsize)
title('Model of Rutherford scattering experiment','fontsize',fsize)
axis tight
grid on
set(gca,'fontsize',fsize)
print( gcf, 'rutherford y = mx+c.png','-dpng','-r300');
close(gcf);

%Graph of alpha particle trajectory
figure( 'name', 'rutherford scattering','color',[1 1 1] )
p = plot( x_traj, y_traj,'r-' );
hold on;
plot( x_us1, y_us1,'r--' );
plot( x_us2, y_us2,'r--' );
plot(x_nuc,y_nuc,'k');
axis equal
xlabel('x /fm','fontsize',fsize);
ylabel('y /fm','fontsize',fsize);
tit = title({['Rutherford \alpha scattering: Z = ',...
    num2str(Z)],['\phi = ',num2str(PHI*180/pi),'^o, E = ',...
    num2str(E/(1e6*qe)),'MeV, u/c = ',num2str(u_over_c)]},...
    'fontsize',fsize);
xlim(xlimits)
ylim(ylimits)
grid on
set(gca,'fontsize',fsize)
print( gcf, 'rutherford trajectory.png','-dpng','-r300');

%Now loop an animation of the trajectory
n=0;
set(gcf,'renderer','painters');
alpha = plot( x_traj(1),y_traj(1),'r*','markersize',20);
while isempty( get(gcf,'Currentkey') )==1
    n=n+1;
    if n>S
        n=1;
    end
    set( p,'xdata',x_traj(1:n),'ydata',y_traj(1:n));
    set( alpha,'xdata',x_traj(n),'ydata',y_traj(n));
    set( tit, 'string', {['Rutherford \alpha scattering: Z = ',...
    num2str(Z)],['\phi = ',num2str(PHI*180/pi),'^o, E = ',...
    num2str(E/(1e6*qe)),'MeV, u/c = ',num2str(u_over_c)],...
    ['t = ',num2str(t(n)),'s']} );
    pause(0.001);
end
close(gcf);

%integrate
% Function that fits a piecwise polynomial to an array of (x,y) data and
% thus computes the definite integral between the points x=a and x=b.
% Note a and b can be arrays, but must be of the same dimensions.
% The function is based on the code written on pages 292 and 294
% of "Mastering Matlab 6" by Duane Hanselman & Bruce Littlefield.
%
% NOTE: seriously erroneous results may occur if a,b values are outside
% the range of array x.
%
% LAST UPDATED by Andrew French. 27/1/2016.
%
% Syntax: I = integrate(a,b,x,y)
%
% x   - Vector of data x variable
% y   - Vector of data y(x) variable
% a   - Array of x starting values for the definite integral of y vs x
% b   - Array of x finishing values for the definite integral of y vs x

function I = integrate(a,b,x,y)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Define type of piecewise polynomial
% computed. Hermite polynomials tend to be better for
% non-smooth data and tends to be 'shape preserving.'

%poly = 'spline';
poly = 'hermite';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Compute piecewise polynomial. Cubic spline is the default
if strcmp(poly,'hermite')==1
    pp=pchip(x,y);
else
    pp=spline(x,y);
end

%Take apart piecewise polynomial
[br,co,npy,nco]=unmkpp(pp);

%Scale factors for integration
sf=nco:-1:1;

%Integral coefficients
ico=[co./sf(ones(npy,1),:) zeros(npy,1)];

%Integral spline has higher order
nco=nco+1;

%Find constant terms in polynomials
for k=2:npy
    ico(k,nco)=polyval(ico(k-1,:),br(k)-br(k-1));
end
ico(1,nco)=0;

%Build pp form for integral
ppi=mkpp(br,ico);

%Evaluate integral at values of a and b
Ia = ppval(ppi,a);
Ib = ppval(ppi,b);

%Define output
I = Ib - Ia;

%End of code